
.. blogpost::
    :title: Building pycrypto on Windows
    :keywords: pycrypto, Windows
    :date: 2017-01-03
    :categories: module

    New version of Python and the same issues come back
    when I need to compile some specific packages such as pycrypto.
    No big issue here. After getting the sources, the following
    instructions might work:

    ::

        python setup.py bdist_wheel

    In my case, I got:

    ::

        C:\Program Files (x86)\Windows Kits\10\include\10.0.10240.0\ucrt\inttypes.h(26): error C2061: syntax error: identifier 'intmax_t'

    I finally decided to edit this file and to add just before the line
    of the error (which I'll remove after):

    ::

        #define intmax_t long long
        #define uintmax_t unsigned long long

    And I was able to build ``pycrypto-2.7a2-cp36-cp36m-win_amd64.whl``.
